@@ -18,26 +18,22 @@
  *
  */
 
+#include <getopt.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <getopt.h>
+#include <bits/getopt_core.h>
 #include <signal.h>
 
 #ifdef USE_MTRACE
 #include <mcheck.h>
 #endif /* USE_MTRACE */
 
-#include <X11/Xlib.h>
-#include <X11/xpm.h>
-#include <X11/extensions/shape.h>
-
-#include "wmgeneral.h"
+#include <libdockapp/wmgeneral.h>
 
 #include "wmmisc-master.xpm"
 #include "dockapp_main.h"
 #include "dockapp_draw.h"
-#include "dockapp_utils.h"
 
 void
 dockapp_show_help( const char* wm_name )
@@ -46,18 +42,17 @@ dockapp_show_help( const char* wm_name )
    printf( "This is a simple WindowMaker 'DockApp' that will monitor the following:\n" );
    printf( "Number of users logged in, total processes, total number of processes running,\n" );
    printf( "the system's fork count and load average.\n\n" );
-   printf( "                -h       display this help and exit\n" );
-   printf( "                -v       output version information and exit\n\n" );
-   printf( "Report bugs to <" DOCKAPP_AUTHOR_EMAIL ">.\n" );
+   printf( "      -h                 display this help and exit\n" );
+   printf( "      -v                 output version information and exit\n" );
+   printf( "      -display DISPLAY   set display\n");
+   printf( "      -geometry +x+y     set position\n\n");
+   printf( "Report bugs to <" PACKAGE_BUGREPORT ">.\n" );
 }
 
 void
 dockapp_show_version( void )
 {
-   printf( "%s %d.%d\n",
-	   DOCKAPP_NAME,
-	   DOCKAPP_MAJOR_VERSION,
-	   DOCKAPP_MINOR_VERSION );
+   printf( "%s\n", PACKAGE_STRING);
    printf( "Written by %s <%s>\n\n", DOCKAPP_AUTHOR, DOCKAPP_AUTHOR_EMAIL );
    printf( "Copyright (C) 2003-2006 %s\n", DOCKAPP_AUTHOR );
    printf( "This is free software; see the source for copying conditions.  There is NO\n" );
@@ -96,7 +91,7 @@ dockapp_crash( int signal_received )
 	    DOCKAPP_NAME );
    fprintf( stderr,
 	    "such as gdb, and report the output to <%s>.\n",
-	    DOCKAPP_AUTHOR_EMAIL );
+	    PACKAGE_BUGREPORT );
 
    abort();
 }
@@ -105,6 +100,11 @@ int
 main( int argc, char** argv )
 {
    int opt = 0;
+   const struct option longopts[] = {
+	{"display", required_argument, NULL, 0},
+	{"geometry", required_argument, NULL, 0},
+	{0, 0, 0, 0}
+   };
 
 #ifdef USE_MTRACE
    mtrace();
@@ -113,7 +113,7 @@ main( int argc, char** argv )
    signal( SIGINT, dockapp_exit );
    signal( SIGSEGV, dockapp_crash );
 
-   opt = getopt( argc, argv, "hv" );
+   opt = getopt_long_only( argc, argv, "hv", longopts, NULL);
 
    while ( -1 != opt )
    {
@@ -134,22 +134,22 @@ main( int argc, char** argv )
 	 }
       }
 
-      opt = getopt( argc, argv, "hv" );
+      opt = getopt_long_only( argc, argv, "hv", longopts, NULL);
    }
 
-   create_xbm_from_xpm( wmmisc_mask_bits,
+   createXBMfromXPM( wmmisc_mask_bits,
 			wmmisc_master_xpm,
 			wmmisc_mask_width,
 			wmmisc_mask_height );
 
-   open_window( argc,
+   openXwindow( argc,
 		argv,
 		wmmisc_master_xpm,
 		wmmisc_mask_bits,
 		wmmisc_mask_width,
 		wmmisc_mask_height );
 
-   redraw_window();
+   RedrawWindow();
 
    dockapp_draw_small_str( "USERS", 4, 4 );
    dockapp_draw_small_str( "PROCS", 4, 11 );
